@@ -65,7 +65,8 @@ e_ews_connection_get_server_version_string (EEwsConnection *cnc)
 }
 
 EEwsServerVersion
-e_ews_debug_get_server_version_from_string (const gchar *version) {
+e_ews_debug_get_server_version_from_string (const gchar *version)
+{
 	if (g_strcmp0 (version, "Exchange2007") == 0)
 		return E_EWS_EXCHANGE_2007;
 	else if (g_strcmp0 (version, "Exchange2007_SP1") == 0)
@@ -82,18 +83,18 @@ e_ews_debug_get_server_version_from_string (const gchar *version) {
 
 static void
 print_header (const gchar *name,
-	       const gchar *value,
-	       gpointer user_data)
+	      const gchar *value,
+	      gpointer user_data)
 {
 	fprintf (user_data, "%s: %s\n", name, value);
 }
 
 static void
 e_ews_debug_dump_raw_soup_message (FILE *out,
-				    SoupMessageHeaders *hdrs,
-				    SoupMessageBody *body)
+				   SoupMessageHeaders *hdrs,
+				   SoupMessageBody *body)
 {
-	if (soup_message_body_get_accumulate (body)) {
+	if (body && soup_message_body_get_accumulate (body)) {
 		SoupBuffer *buffer;
 
 		buffer = soup_message_body_flatten (body);
@@ -102,9 +103,12 @@ e_ews_debug_dump_raw_soup_message (FILE *out,
 
 	/* print body */
 	fprintf (out, " =====================\n");
-	soup_message_headers_foreach (hdrs, print_header, out);
+	if (hdrs)
+		soup_message_headers_foreach (hdrs, print_header, out);
+	else
+		fprintf (out, " null headers\n");
 	fputc ('\n', out);
-	if (body->data) {
+	if (body && body->data) {
 		fputs (body->data, out);
 		fputc ('\n', out);
 	}
