@@ -302,6 +302,7 @@ e_ews_notification_subscribe_folder_sync (EEwsNotification *notification,
 	ESoapMessage *msg;
 	ESoapResponse *response;
 	ESoapParameter *param, *subparam;
+	CamelEwsSettings *settings;
 	GError *error = NULL;
 	GSList *l;
 	guint event_type;
@@ -315,7 +316,10 @@ e_ews_notification_subscribe_folder_sync (EEwsNotification *notification,
 	if (!notification->priv->connection)
 		return FALSE;
 
+	settings = e_ews_connection_ref_settings (notification->priv->connection);
+
 	msg = e_ews_message_new_with_header (
+		settings,
 		e_ews_connection_get_uri (notification->priv->connection),
 		e_ews_connection_get_impersonate_user (notification->priv->connection),
 		"Subscribe",
@@ -326,6 +330,8 @@ e_ews_notification_subscribe_folder_sync (EEwsNotification *notification,
 		FALSE,
 		FALSE);
 
+	g_clear_object (&settings);
+
 	if (!msg) {
 		g_warning ("%s: Failed to create Soup message for URI '%s'", G_STRFUNC, e_ews_connection_get_uri (notification->priv->connection));
 		return FALSE;
@@ -439,6 +445,7 @@ e_ews_notification_unsubscribe_folder_sync (EEwsNotification *notification,
 	ESoapMessage *msg;
 	ESoapResponse *response;
 	ESoapParameter *param;
+	CamelEwsSettings *settings;
 	GError *error = NULL;
 	xmlDoc *doc;
 
@@ -449,7 +456,10 @@ e_ews_notification_unsubscribe_folder_sync (EEwsNotification *notification,
 	if (!notification->priv->connection)
 		return FALSE;
 
+	settings = e_ews_connection_ref_settings (notification->priv->connection);
+
 	msg = e_ews_message_new_with_header (
+		settings,
 		e_ews_connection_get_uri (notification->priv->connection),
 		e_ews_connection_get_impersonate_user (notification->priv->connection),
 		"Unsubscribe",
@@ -460,6 +470,8 @@ e_ews_notification_unsubscribe_folder_sync (EEwsNotification *notification,
 		FALSE,
 		FALSE);
 
+	g_clear_object (&settings);
+
 	if (!msg) {
 		g_warning ("%s: Failed to create Soup message for URI '%s'", G_STRFUNC, e_ews_connection_get_uri (notification->priv->connection));
 		return FALSE;
@@ -643,6 +655,26 @@ ews_notification_fire_events_from_response (EEwsNotification *notification,
 	return TRUE;
 }
 
+static gboolean
+ews_abort_session_idle_cb (gpointer user_data)
+{
+	SoupSession *session = user_data;
+
+	g_return_val_if_fail (SOUP_IS_SESSION (session), FALSE);
+
+	soup_session_abort (session);
+
+	return FALSE;
+}
+
+static void
+ews_notification_schedule_abort (SoupSession *session)
+{
+	g_return_if_fail (SOUP_IS_SESSION (session));
+
+	g_idle_add_full (G_PRIORITY_HIGH_IDLE, ews_abort_session_idle_cb, g_object_ref (session), g_object_unref);
+}
+
 static void
 ews_notification_soup_got_chunk (SoupMessage *msg,
 				 SoupBuffer *chunk,
@@ -702,7 +734,7 @@ ews_notification_soup_got_chunk (SoupMessage *msg,
 		}
 
 		if (!ews_notification_fire_events_from_response (notification, response)) {
-			soup_session_abort (notification->priv->soup_session);
+			ews_notification_schedule_abort (notification->priv->soup_session);
 
 			g_object_unref (response);
 			break;
@@ -721,8 +753,8 @@ ews_notification_soup_got_chunk (SoupMessage *msg,
 			keep_parsing = FALSE;
 
 			if (cancelled) {
-				/* Abort any pending operations */
-				soup_session_abort (notification->priv->soup_session);
+				/* Abort any pending operations, but not here, rather in another thread */
+				ews_notification_schedule_abort (notification->priv->soup_session);
 			}
 		}
 	} while (keep_parsing);
@@ -734,6 +766,7 @@ e_ews_notification_get_events_sync (EEwsNotification *notification,
 				    gboolean *out_fatal_error)
 {
 	ESoapMessage *msg;
+	CamelEwsSettings *settings;
 	gboolean ret;
 	gulong handler_id;
 	guint status_code;
@@ -746,7 +779,10 @@ e_ews_notification_get_events_sync (EEwsNotification *notification,
 	g_return_val_if_fail (notification->priv != NULL, FALSE);
 	g_return_val_if_fail (notification->priv->connection != NULL, FALSE);
 
+	settings = e_ews_connection_ref_settings (notification->priv->connection);
+
 	msg = e_ews_message_new_with_header (
+		settings,
 		e_ews_connection_get_uri (notification->priv->connection),
 		e_ews_connection_get_impersonate_user (notification->priv->connection),
 		"GetStreamingEvents",
@@ -757,6 +793,8 @@ e_ews_notification_get_events_sync (EEwsNotification *notification,
 		FALSE,
 		FALSE);
 
+	g_clear_object (&settings);
+
 	if (!msg) {
 		g_warning ("%s: Failed to create Soup message for URI '%s'", G_STRFUNC, e_ews_connection_get_uri (notification->priv->connection));
 		return FALSE;
@@ -792,7 +830,7 @@ static void
 ews_notification_cancelled_cb (GCancellable *cancellable,
 			       SoupSession *session)
 {
-	soup_session_abort (session);
+	ews_notification_schedule_abort (session);
 }
 
 static gpointer
