@@ -463,6 +463,7 @@ ews_oof_settings_initable_init_async (GAsyncInitable *initable,
 	EEwsOofSettings *settings;
 	EEwsConnection *connection;
 	ESoapMessage *message;
+	CamelEwsSettings *ews_settings;
 	const gchar *uri, *impersonate_user;
 	const gchar *mailbox;
 	EEwsServerVersion version;
@@ -474,8 +475,10 @@ ews_oof_settings_initable_init_async (GAsyncInitable *initable,
 	impersonate_user = e_ews_connection_get_impersonate_user (connection);
 	mailbox = e_ews_connection_get_mailbox (connection);
 	version = e_ews_connection_get_server_version (connection);
+	ews_settings = e_ews_connection_ref_settings (connection);
 
 	message = e_ews_message_new_with_header (
+		ews_settings,
 		uri,
 		impersonate_user,
 		"GetUserOofSettingsRequest",
@@ -486,6 +489,8 @@ ews_oof_settings_initable_init_async (GAsyncInitable *initable,
 		FALSE,
 		TRUE);
 
+	g_clear_object (&ews_settings);
+
 	e_soap_message_start_element (message, "Mailbox", NULL, NULL);
 	e_ews_message_write_string_parameter (
 		message, "Address", NULL, mailbox);
@@ -972,6 +977,7 @@ e_ews_oof_settings_submit (EEwsOofSettings *settings,
 	gchar *start_time;
 	gchar *end_time;
 	EEwsServerVersion version;
+	CamelEwsSettings *ews_settings;
 
 	g_return_if_fail (E_IS_EWS_OOF_SETTINGS (settings));
 
@@ -980,6 +986,7 @@ e_ews_oof_settings_submit (EEwsOofSettings *settings,
 	uri = e_ews_connection_get_uri (connection);
 	impersonate_user = e_ews_connection_get_impersonate_user (connection);
 	version = e_ews_connection_get_server_version (connection);
+	ews_settings = e_ews_connection_ref_settings (connection);
 
 	internal_reply = e_ews_oof_settings_dup_internal_reply (settings);
 	external_reply = e_ews_oof_settings_dup_external_reply (settings);
@@ -993,6 +1000,7 @@ e_ews_oof_settings_submit (EEwsOofSettings *settings,
 	g_date_time_unref (date_time);
 
 	message = e_ews_message_new_with_header (
+		ews_settings,
 		uri,
 		impersonate_user,
 		"SetUserOofSettingsRequest",
@@ -1003,6 +1011,8 @@ e_ews_oof_settings_submit (EEwsOofSettings *settings,
 		FALSE,
 		TRUE);
 
+	g_clear_object (&ews_settings);
+
 	/* <Mailbox> */
 
 	e_soap_message_start_element (
